import type { SyntaxHighlighterProps } from 'src/types/shiki'
import React from 'react'
import { Platform, Text, View } from 'react-native'
import { useSyntaxHighlighter } from '../../hooks/useSyntaxHighlighter'
import SyntaxLine from './SyntaxLine'

const monospaceFont = Platform.select({
  ios: 'Menlo',
  android: 'monospace',
  default: 'monospace',
})

function SyntaxHighlighter({ text, language, languageId, theme, fontSize = 14 }: SyntaxHighlighterProps & { fontSize?: number }) {
  const { tokens, error, isLoading } = useSyntaxHighlighter({
    text,
    language,
    languageId,
    theme,
  })

  if (error) {
    return (
      <Text
        style={{
          color: '#ff6b6b',
          fontFamily: monospaceFont,
          fontSize,
          padding: 4,
        }}
      >
        Error:
        {' '}
        {error}
      </Text>
    )
  }

  if (isLoading) {
    return (
      <Text
        style={{
          color: '#666666',
          fontFamily: monospaceFont,
          fontSize,
          padding: 4,
        }}
      >
        Loading...
      </Text>
    )
  }

  return (
    <View style={{ flex: 1 }}>
      {tokens.map((line, lineIndex) => (
        <View
          key={`line-${lineIndex}`}
          style={{
            minHeight: fontSize * 1.5, // Ensure consistent line height
            paddingVertical: 2,
          }}
        >
          <SyntaxLine line={line} fontSize={fontSize} />
        </View>
      ))}
    </View>
  )
}

export default SyntaxHighlighter
