import type { TokenType } from '../../types'
import React from 'react'
import { Platform, Text, View } from 'react-native'

const monospaceFont = Platform.select({
  ios: 'Menlo',
  android: 'monospace',
  default: 'monospace',
})

interface SyntaxLineProps {
  line: TokenType[]
  fontSize?: number
}

function SyntaxLine({ line, fontSize = 14 }: SyntaxLineProps) {
  return (
    <View
      style={{
        flexDirection: 'row',
        flexWrap: 'wrap',
        minHeight: fontSize * 1.5, // Match parent container
      }}
    >
      {line.map((token, tokenIndex) => {
        const content = token.content.replace(/ /g, '\u00A0')
        return (
          <Text
            key={`${tokenIndex}-${content.slice(0, 8)}`}
            style={{
              color: token.color || '#FFFFFF',
              fontFamily: monospaceFont,
              fontSize,
              fontStyle: token.fontStyle as 'normal' | 'italic',
              fontWeight: token.fontWeight as 'normal' | 'bold',
              includeFontPadding: false,
              textAlignVertical: 'center',
              lineHeight: fontSize * 1.5,
              ...(Platform.OS === 'ios'
                ? {
                    paddingTop: 2, // Fine-tune iOS vertical alignment
                  }
                : {}),
            }}
          >
            {content}
          </Text>
        )
      })}
      <Text
        style={{
          fontFamily: monospaceFont,
          fontSize,
          color: 'transparent',
          lineHeight: fontSize * 1.5,
          height: fontSize * 1.5,
        }}
      >
        {'\n'}
      </Text>
    </View>
  )
}

export default SyntaxLine
